@@ -7,7 +7,7 @@ import shutil
 import sys
 
 from qBitrr.bundled_data import license_text, patched_version
-from qBitrr.gen_config import MyConfig
+from qBitrr.gen_config import MyConfig, generate_doc
 
 APPDATA_FOLDER = pathlib.Path().home().joinpath(".config", "qBitManager")
 APPDATA_FOLDER.mkdir(parents=True, exist_ok=True)
@@ -19,7 +19,7 @@ def process_flags() -> argparse.Namespace | bool:
         "--gen-config",
         "-gc",
         dest="gen_config",
-        help="Generate a config file in the current working directory.",
+        help="Generate a config file in the current working directory",
         action="store_true",
     )
     parser.add_argument(
@@ -27,7 +27,12 @@ def process_flags() -> argparse.Namespace | bool:
     )
 
     parser.add_argument(
-        "-l", "--license", dest="license", action="store_const", const=license_text
+        "-l",
+        "--license",
+        dest="license",
+        action="store_const",
+        const=license_text,
+        help="Show the qBitrr's licence",
     )
     parser.add_argument(
         "-s",
@@ -35,6 +40,7 @@ def process_flags() -> argparse.Namespace | bool:
         action="store_const",
         dest="source",
         const="Source code can be found on: https://github.com/Drapersniper/Qbitrr",
+        help="Shows a link to qBitrr's source",
     )
 
     args = parser.parse_args()
@@ -57,7 +63,24 @@ COPIED_TO_NEW_DIR = False
 file = "config.toml"
 CONFIG_FILE = APPDATA_FOLDER.joinpath(file)
 CONFIG_PATH = pathlib.Path(f"./{file}")
-if not CONFIG_FILE.exists() and not CONFIG_PATH.exists():
+if any(
+    a in sys.argv
+    for a in [
+        "--gen-config",
+        "-gc",
+        "--version",
+        "-v",
+        "--license",
+        "-l",
+        "--source",
+        "-s",
+        "-h",
+        "--help",
+    ]
+):
+    CONFIG = MyConfig(CONFIG_FILE, config=generate_doc())
+    COPIED_TO_NEW_DIR = None
+elif (not CONFIG_FILE.exists()) and (not CONFIG_PATH.exists()):
     print(f"{file} has not been found")
     print(f"{file} must be added to {CONFIG_FILE}")
     print(
@@ -66,7 +89,7 @@ if not CONFIG_FILE.exists() and not CONFIG_PATH.exists():
     )
     sys.exit(1)
 
-if CONFIG_FILE.exists():
+elif CONFIG_FILE.exists():
     CONFIG = MyConfig(CONFIG_FILE)
 else:
     with contextlib.suppress(
